==> QLC%2B_4.12.6.tar.gz: qlcplus-QLC-_4.12.6/plugins/udmx/src/uDMX_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>UDMX</name>
    <message>
        <location filename="udmx.cpp" line="101"/>
        <source>This plugin provides DMX output support for Anyma uDMX devices.</source>
        <translation>Dieses Plugin bietet DMX-Output für Anyma uDMX Geräte.</translation>
    </message>
    <message>
        <location filename="udmx.cpp" line="195"/>
        <source>Do you wish to re-scan your hardware?</source>
        <translation>Nach neuer Hardware suchen?</translation>
    </message>
</context>
<context>
    <name>UDMXDevice</name>
    <message>
        <location filename="udmxdevice.cpp" line="130"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="151"/>
        <source>DMX Channels</source>
        <translation>DMX Kanäle</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="153"/>
        <source>DMX Frame Frequency</source>
        <translation>DMX-Rahmen-Frequenz</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="156"/>
        <source>Bad</source>
        <translation>Schlecht</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="158"/>
        <source>Good</source>
        <translation>Gut</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="160"/>
        <source>Patch this device to a universe to find out.</source>
        <translation>Patche dieses Gerät zu einem herauszufindendem Universum.</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="161"/>
        <source>System Timer Accuracy</source>
        <translation>System-Timer Genauigkeit</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="166"/>
        <source>Unknown device</source>
        <translation>Unbekanntes Gerät</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="168"/>
        <source>Cannot connect to USB device.</source>
        <translation>Kann nicht mit dem USB-Gerät verbinden.</translation>
    </message>
</context>
</TS>

==> QLC%2B_4.14.0.tar.gz: qlcplus-QLC-_4.14.0/plugins/udmx/src/uDMX_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>UDMX</name>
    <message>
        <location filename="udmx.cpp" line="100"/>
        <source>This plugin provides DMX output support for Anyma uDMX devices.</source>
        <translation>Dieses Plugin bietet DMX-Output für Anyma uDMX Geräte.</translation>
    </message>
    <message>
        <location filename="udmx.cpp" line="199"/>
        <source>Do you wish to re-scan your hardware?</source>
        <translation>Nach neuer Hardware suchen?</translation>
    </message>
</context>
<context>
    <name>UDMXDevice</name>
    <message>
        <location filename="udmxdevice.cpp" line="122"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="142"/>
        <source>Device name</source>
        <translation>Gerätename</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="144"/>
        <source>DMX Channels</source>
        <translation>DMX Kanäle</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="146"/>
        <source>DMX Frame Frequency</source>
        <translation>DMX-Rahmen-Frequenz</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="149"/>
        <source>Bad</source>
        <translation>Schlecht</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="151"/>
        <source>Good</source>
        <translation>Gut</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="153"/>
        <source>Patch this device to a universe to find out.</source>
        <translation>Patche dieses Gerät zu einem herauszufindenden Universum.</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="154"/>
        <source>System Timer Accuracy</source>
        <translation>System-Timer-Genauigkeit</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="159"/>
        <source>Device not in use</source>
        <translation>Gerät nicht in Verwendung</translation>
    </message>
</context>
</TS>
